@@ -1,6 +1,5 @@
 from typing import Callable
 
-import grpc
 from frogml.core.exceptions import FrogmlException
 
 
@@ -10,13 +9,7 @@ def grpc_try_catch_wrapper(exception_message: str):
             try:
                 return function(*args, **kwargs)
             except Exception as e:
-                if isinstance(e, grpc.RpcError):
-                    # noinspection PyUnresolvedReferences
-                    raise FrogmlException(
-                        exception_message + f". Error is: {e}."
-                    ) from e
-
-                raise e
+                raise FrogmlException(f"{exception_message}. Error is: {e}.") from e
 
         return _inner_wrapper
 
