@@ -2,10 +2,14 @@ from datetime import timedelta
 from functools import lru_cache
 from pathlib import Path
 from tempfile import TemporaryDirectory
-from typing import TYPE_CHECKING, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Union, Iterable
 
 import requests
 from frogml._proto.qwak.build.v1.build_pb2 import DESCRIPTOR
+from frogml._proto.qwak.models.models_pb2 import (
+    ListModelsMetadataResponse,
+    ModelMetadata as ModelMetadataProto,
+)
 from requests import Response
 from requests.auth import AuthBase
 
@@ -472,10 +476,10 @@ class FrogMLClient:
             model_id (str): The model ID
 
         Returns:
-             Optional[BaseModel]: Model by ID.
+             Optional[Model]: Model by ID.
 
         """
-        return BaseModel.from_proto(
+        return Model.from_proto(
             self._get_model_management().get_model(model_id=model_id)
         )
 
@@ -487,14 +491,18 @@ class FrogMLClient:
         Returns:
             List[ModelMetadata]: List of model metadata
         """
-        service_response = self._get_model_management().list_models_metadata(project_id)
-        model_metadata_from_service = service_response.model_metadata
+        service_response: ListModelsMetadataResponse = (
+            self._get_model_management().list_models_metadata(project_id)
+        )
+        model_metadata_from_service: Iterable[ModelMetadataProto] = (
+            service_response.model_metadata
+        )
 
-        result = []
+        result: List[ModelMetadata] = []
         for metadata_source in model_metadata_from_service:
             model_metadata = ModelMetadata()
 
-            model_metadata.model = BaseModel.from_proto(metadata_source.model)
+            model_metadata.model = Model.from_proto(metadata_source.model)
             model_metadata.deployed_builds = [
                 Build.from_proto(build) for build in metadata_source.build
             ]
